summaryrefslogtreecommitdiff
path: root/test/test-kdbus.c
diff options
context:
space:
mode:
Diffstat (limited to 'test/test-kdbus.c')
-rw-r--r--test/test-kdbus.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/test-kdbus.c b/test/test-kdbus.c
index 3cefe0828f8..1314a47b58d 100644
--- a/test/test-kdbus.c
+++ b/test/test-kdbus.c
@@ -404,8 +404,8 @@ static int check_hello(struct kdbus_check_env *env)
fd = open(env->buspath, O_RDWR|O_CLOEXEC);
ASSERT_RETURN(fd >= 0);
- /* no STARTER flag without a name */
- hello.conn_flags = KDBUS_HELLO_STARTER;
+ /* no ACTIVATOR flag without a name */
+ hello.conn_flags = KDBUS_HELLO_ACTIVATOR;
ret = ioctl(fd, KDBUS_CMD_HELLO, &hello);
ASSERT_RETURN(ret == -1 && errno == EINVAL);